#
# spec file for package ode
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define so_maj  3
%define lname   libode%{so_maj}

Name:           ode
Url:            http://ode.org/
Summary:        Open Dynamics Engine Library
License:        LGPL-2.1+ or BSD-3-Clause or Zlib
Group:          Development/Libraries/C and C++
Version:        0.13
Release:        3.1
Source0:        https://sourceforge.net/projects/opende/files/ODE/%{version}/ode-%{version}.tar.bz2
Source9:        ode-config.1

BuildRequires:  Mesa-devel
BuildRequires:  freeglut-devel
BuildRequires:  gcc-c++
BuildRequires:  pkgconfig

%description
ODE is an open source, high performance library for simulating rigid
body dynamics. It is fully featured, stable, mature and platform
independent with an easy to use C/C++ API. It has advanced joint types
and integrated collision detection with friction. ODE is useful for
simulating vehicles, objects in virtual reality environments and
virtual creatures. It is currently used in many computer games, 3D
authoring tools and simulation tools.

%package -n %{lname}
Summary:        Open Dynamics Engine Library development files
Group:          System/Libraries

%description -n %{lname}
ODE is an open source, high performance library for simulating rigid
body dynamics. It is fully featured, stable, mature and platform
independent with an easy to use C/C++ API. It has advanced joint types
and integrated collision detection with friction. ODE is useful for
simulating vehicles, objects in virtual reality environments and
virtual creatures. It is currently used in many computer games, 3D
authoring tools and simulation tools.

%package devel
Summary:        Open Dynamics Engine Library development files
Group:          Development/Libraries/C and C++
Requires:       %{lname} = %{version}
Provides:       libode-devel = %{version}

%description devel
ODE is an open source, high performance library for simulating rigid
body dynamics. It is fully featured, stable, mature and platform
independent with an easy to use C/C++ API. It has advanced joint types
and integrated collision detection with friction. ODE is useful for
simulating vehicles, objects in virtual reality environments and
virtual creatures. It is currently used in many computer games, 3D
authoring tools and simulation tools.

%prep
%setup -q -n ode-%{version}

%build
#autoreconf -fi
CFLAGS="%{optflags} -fno-strict-aliasing"
CXXFLAGS="$CFLAGS"
export CFLAGS CXXFLAGS
export X_LIBS="-lX11"
%configure --enable-shared --disable-static
make V=1 %{?_smp_mflags}

%install
make V=1 %{?_smp_mflags} DESTDIR=%{buildroot} install
mkdir -p %{buildroot}%{_mandir}/man1
gzip -c9 %{SOURCE9} | tee -a %{buildroot}%{_mandir}/man1/ode-config.1.gz
find %{buildroot} -type f -name "*.la" -delete -print

%ifarch %{ix86}
# Fail.
%else
%check
make V=1 %{?_smp_mflags} check
%endif

%post -n %{lname} -p /sbin/ldconfig
%postun -n %{lname} -p /sbin/ldconfig

%files -n %{lname}
%defattr(-,root,root)
%doc LICENSE.TXT README.txt CHANGELOG.txt COPYING
%{_libdir}/libode.so.%{so_maj}.*

%files devel
%defattr(-,root,root)
%{_bindir}/ode-config
%{_mandir}/man1/ode-config.1.gz
%{_includedir}/ode
%{_libdir}/libode.so
%{_libdir}/libode.so.%{so_maj}
%{_libdir}/pkgconfig/*.pc

%changelog
* Thu May 26 2016 dap.darkness@gmail.com
- Update to 0.13:
  * Stable, implicit gyroscopic forces.
  * New joint: transmission joint.
  * Contacts now have rolling friction.
  * Removed the need for defining dSINGLE/dDOUBLE.
  * New joint: Double Ball (AKA "distance joint").
  * New joint: Double Hinge.
  * Threaded execution support interface added (experimental).
  * Many bugs were fixed.
- General clean-up via `spec-cleaner`.
- Source tag was fixed up to use the upstream download URL.
- License tag was fixed. Thanks to @AndreasStieger.
- BuildRequires tags were fixed up.
- Project should have the same name as upstream & pkgconfig.
- Added simple man page for ode-config.
- Added `make check` section (fails for i586).
* Sun Feb 19 2012 jengelh@medozas.de
- Use proper LIBS variable for slipping in X11
  (Libs in LDFLAGS may not have any effect due to importance of
  linking order)
* Mon Nov 21 2011 jengelh@medozas.de
- Remove redundant/unwanted tags/section (cf. specfile guidelines)
- Call configure properly to put libs where they are supposed to be
- Use %%_smp_mflags for parallel building
- Produce shared libraries
* Sat Nov 19 2011 seife+obs@b1-systems.com
- update to 0.11.1
  * lots of new functions and bugfixes, see CHANGELOG.txt
  * add pkgconfig file
- fix build for > 11.4 (add -lX11 explicitly)
- use $RPM_OPT_FLAGS for building
* Mon Aug 11 2008 sndirsch@suse.de
- update to 0.10.1
  * New function: dJointSetPistonAnchorOffset
  * Add new function dJointSetHingeAxisDelta
  * Fix problem with dJointGetPistonPosition and
    dJointGetPistonPositionRate when the joint is attached to only
    a body 2. The sign was inversed.
  * Update the slider joint to have the same behavior as the other
    joint when there is only a body2 attached to it.
  * Rename the new function dJointSetHingeAxisDelta to
    dJointSetHingeAxisOffset. This will remove confusion with the
    old function dJointSetHingeAnchorDelta.
  * Bug fix: Max Correcting Vel behavior is now the same as before
    0.10.
* Sat Jul 19 2008 sndirsch@suse.de
- update to 0.10
  * current stable release
* Wed Nov 21 2007 sndirsch@suse.de
- update to 0.9
  * latest stable release
* Thu May 24 2007 sndirsch@suse.de
- added -devel package to make rpmlint happy
* Thu May 10 2007 sndirsch@suse.de
- updated to 0.8
* Thu Mar 29 2007 coolo@suse.de
- fix BuildRequires (unzip)
* Fri Oct 20 2006 sndirsch@suse.de
- updated to 0.7
* Mon Jun  5 2006 sndirsch@suse.de
- updated to 0.6-rc3
  * Added Convex primitive collision code,
    currently only convex-sphere and convex-plane work
  * Added program to test trimesh vs sphere: ode/test/test_basket
  * Added new autogenerated Visual Studio projects, with Premake scripts
  * Added plane/cyl intersection test
  * Renamed CCylinder to Capsule
  * Added support for geom offsets.
  * Removed LIBTOOL from autotools since it was not really required.
  * Added a target to build ODE as a shared library, this shared
    library gets build alongside the static one, no flags required.
  * dRandInt changed for a non-double all-int version.
  * mics minor fixes and improvements.
  * Fixed segmentation fault with OPCODE on 64 bits systems.
  * Fixed timer.cpp compiler error on x86-64 using GCC.
  * Added trimesh preprocessing to mark unneeded edges and verts.  Also
    added support for preprocessed info to the ccylinder-trimesh
    collider.
  * Important AMotors bugfix
  * Assorted small bugfixes and tweaks for
    trimesh_{box,ccylinder,trimesh} collisions
  * added functions to joint.cpp to allow joint attachment to moving
    geoms.
  * added malloc-based memory allocation in step.cpp & lcp.cpp (turned
    on with a #define switch in common.h)
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Fri Nov 25 2005 sndirsch@suse.de
- added -fno-strict-aliasing to fix build
* Thu Nov 10 2005 sndirsch@suse.de
- created package
